@@ -1,11 +1,10 @@
 (* approx: proxy server for Debian archive files
-   Copyright (C) 2007  Eric C. Cooper <ecc@cmu.edu>
+   Copyright (C) 2008  Eric C. Cooper <ecc@cmu.edu>
    Released under the GNU General Public License *)
 
 open Printf
 open Util
 open Log
-open Default_config
 
 type paragraph = (string * string) list
 
@@ -49,14 +48,14 @@ let read_paragraph chan =
     | None when lines = [] -> raise End_of_file
     | None | Some "" -> lines
     | Some line when line.[0] = ' ' || line.[0] = '\t' ->
-	(match lines with
-	| last :: others ->
-	    let line =
-	      if line = " ." then ""
-	      else substring line ~from: 1
-	    in
-	    loop ((last ^ "\n" ^ line) :: others)
-	| [] -> failwith ("leading white space: " ^ line))
+        (match lines with
+        | last :: others ->
+            let line =
+              if line = " ." then ""
+              else substring line ~from: 1
+            in
+            loop ((last ^ "\n" ^ line) :: others)
+        | [] -> failwith ("leading white space: " ^ line))
     | Some line -> loop (line :: lines)
   in
   List.rev_map parse (loop [])
@@ -146,8 +145,8 @@ let is_valid checksum ((s, n) as info) file =
   match validate ~checksum info file with
   | Valid -> true
   | Wrong_size n' ->
-      if debug then debug_message "%s: size %Ld should be %Ld" file n' n;
+      debug_message "%s: size %Ld should be %Ld" file n' n;
       false
   | Wrong_checksum s' ->
-      if debug then debug_message "%s: checksum %s should be %s" file s' s;
+      debug_message "%s: checksum %s should be %s" file s' s;
       false
